<!--
SPDX-FileCopyrightText: 2025 Ivan Perevala <ivan95perevala@gmail.com>

SPDX-License-Identifier: GPL-3.0-or-later
-->

# UI components for Blender extensions

![logo](https://raw.githubusercontent.com/ivan-perevala/lib_bhqui/main/.github/images/logo-dark.svg)

[![License: GPL-3.0-or-later](https://img.shields.io/badge/license-GPLv3-yellow.svg)](https://www.gnu.org/licenses/gpl-3.0-standalone.html)

See [./LICENSE](./LICENSE) file for license.

© 2025 Ivan Perevala (ivan95perevala@gmail.com)
